# コントリビューター行動規範

## 私たちの誓い

私たちは、メンバー、コントリビューター、リーダーとして、あらゆる年齢、体型、可視化または不可視化された障害、民族性、性的特徴、性同一性と表現、経験レベル、教育、社会経済的地位、国籍、外見、人種、宗教、性的アイデンティティおよび指向に関わらず、誰もがハラスメントのない体験ができるコミュニティへの参加を誓います。

私たちは、オープンで歓迎的で多様性に富み、包括的で健全なコミュニティに貢献する方法で行動し、交流することを誓います。

## 私たちの基準

私たちのコミュニティにとってポジティブな環境を築く行動の例には、以下が含まれます：

* 他の人々に対して共感と思いやりを示すこと
* 異なる意見、視点、経験を尊重すること
* 建設的なフィードバックを与え、優雅に受け入れること
* 責任を受け入れ、私たちの過ちによって影響を受けた人々に謝罪し、
  その経験から学ぶこと
* 個人としてだけでなく、コミュニティ全体にとって最善なことに焦点を当てること

容認できない行動の例には以下が含まれます：

* 性的な言語やイメージの使用、およびあらゆる種類の性的な関心やアプローチ
* 荒らし、侮辱的または軽蔑的なコメント、個人的または政治的な攻撃
* 公的または私的な嫌がらせ
* 明示的な許可なしに、物理的またはメールアドレスなど他人のプライベート情報を公開すること
* 専門的な環境において不適切と合理的に考えられるその他の行為

## 施行責任

コミュニティリーダーは、許容される行動基準を明確にし、施行する責任があり、不適切、脅威的、攻撃的、または有害と判断される行動に対して適切かつ公正な是正措置を講じます。

コミュニティリーダーは、この行動規範に沿わないコメント、コミット、コード、Wiki 編集、Issue、その他の貢献を削除、編集、または拒否する権利と責任を有し、適切な場合にはモデレーション決定の理由を説明します。

## スコープ

この行動規範は、すべてのコミュニティスペース内で適用され、また個人が公式にコミュニティを代表して公共の場で行動する場合にも適用されます。
私たちのコミュニティを代表する例としては、公式のメールアドレスを使用する、公式のソーシャルメディアアカウントを通じて投稿する、またはオンラインまたはオフラインのイベントで任命された代表者として行動するなどが含まれます。

## 強制実行

虐待的、嫌がらせ的、またはその他の容認できない行為の事例は、
施行を担当するコミュニティリーダーに aw@funstory.ai まで報告してください。
すべての苦情は迅速かつ公平に審査および調査されます。

すべてのコミュニティリーダーは、いかなる事件の報告者のプライバシーとセキュリティを尊重する義務があります。

## 施行ガイドライン

コミュニティリーダーは、この行動規範に違反すると判断した行動に対して、以下のコミュニティ影響ガイドラインに従って結果を決定します：

### 1. 修正

**コミュニティへの影響**: 不適切な言語の使用や、コミュニティにおいて非専門的または歓迎されないとみなされるその他の行動。

**結果**: コミュニティリーダーからの非公開の書面による警告。違反の性質と、なぜその行動が不適切であったかについての説明が提供されます。公開謝罪が求められる場合があります。

### 2. 警告

**コミュニティへの影響**: 単一のインシデントまたは一連の行動による違反。

**結果**: 継続的な行動に対する結果を伴う警告。指定された期間、関係者とのやり取り（行動規範を施行する人々への一方的な接触を含む）を禁止します。これには、コミュニティスペースだけでなく、ソーシャルメディアなどの外部チャネルでのやり取りも含まれます。これらの条件に違反すると、一時的または永久的な利用禁止になる可能性があります。

### 3. 一時的な利用禁止

**コミュニティへの影響**: コミュニティ基準の重大な違反、持続的な不適切な行動を含む。

**結果**: 指定された期間、コミュニティとのあらゆる種類の交流や公開コミュニケーションを一時的に禁止する。この期間中は、関係者との公的または私的な交流、行動規範を施行する人々への未承諾の接触も許可されない。これらの条件に違反すると、永久追放につながる可能性がある。

### 4. 永久追放

**コミュニティへの影響**: コミュニティの基準に違反するパターンを示す行為、持続的な不適切な行動、個人への嫌がらせ、または特定のグループに対する攻撃や中傷を含む。

**結果**: コミュニティ内でのあらゆる種類の公開的な関与からの永久追放。

## 帰属

この行動規範は[Contributor Covenant][homepage]、
バージョン 2.0 から改変したもので、
https://www.contributor-covenant.org/version/2/0/code_of_conduct.html で利用可能です。

コミュニティ影響ガイドラインは[Mozilla の行動規範施行ラダー](https://github.com/mozilla/diversity)に着想を得ています。

[homepage]: https://www.contributor-covenant.org

この行動規範に関するよくある質問への回答は、
https://www.contributor-covenant.org/faq の FAQ を参照してください。
翻訳は https://www.contributor-covenant.org/translations で利用可能です。

<div align="right"> 
<h6><small>このページの一部のコンテンツは GPT によって翻訳されており、エラーが含まれている可能性があります。</small></h6>